package VMOMI::HostIpConfigIpV6AddressConfigType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
